---
test_data: TD_38_03_48_51
test_title: large data set
---

Large generated data set.

```
[code_maturity] * [geo_region] * [flow_stage] * [host_name] * [service_name] = 100_000 services
10              * 10           * 10           * 10          * 10             = 100_000

The total set of `data_envelope`-s:
*   1_000       * clusters
*   10_000      * hosts
*   100_000     * services
```
